import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { Conversation, GetConversationApplicationErrors, ParticipantId, GetOrCreateConversationResponse, ConversationConversationsMergedEnvelope } from './index.typings.mjs';
export { ActionEvent, AddConversationChannelsRequest, AddConversationChannelsResponse, BaseEventMetadata, ChannelType, ChatroomsMerged, ConversationChannel, ConversationDisplayData, ConversationsMerged, CursorPaging, Cursors, DeleteConversationRequest, DeleteConversationResponse, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GetConversationRequest, GetConversationResponse, GetOrCreateConversationRequest, IdentificationData, IdentificationDataIdOneOf, ListConversationsRequest, ListConversationsResponse, MessageEnvelope, PagingMetadataV2, ParticipantIdIdOneOf, ReadConversationRequest, ReadConversationResponse, RestoreInfo, SortOrder, Sorting, WebhookIdentityType, WebhooksIdentificationData, WebhooksIdentificationDataIdOneOf } from './index.typings.mjs';

type ConversationNonNullablePaths = `_id` | `participant.anonymousVisitorId` | `participant.memberId` | `channels` | `businessDisplayData.name` | `participantDisplayData.name`;
declare function getConversation$1(httpClient: HttpClient): GetConversationSignature;
interface GetConversationSignature {
    /**
     * Retrieves a conversation by conversation ID.
     *
     * If you don't have the conversation ID, use Get Or Create Conversation in the Conversations API
     * to retrieve the conversation with the visitor, contact, or member ID.
     * @param - Conversation ID.
     * @returns Retrieved conversation.
     */
    (conversationId: string): Promise<NonNullablePaths<Conversation, ConversationNonNullablePaths> & {
        __applicationErrorsType?: GetConversationApplicationErrors;
    }>;
}
declare function getOrCreateConversation$1(httpClient: HttpClient): GetOrCreateConversationSignature;
interface GetOrCreateConversationSignature {
    /**
     * Retrieves a conversation by the specified visitor, contact, or member ID. If the conversation doesn't exist for the specified visitor, contact, or member, the method creates a new conversation.
     * @param - ID of the visitor, contact, or member chatting with the business.
     *
     * Required for 3rd-party apps.
     * @param - null
     */
    (participantId: ParticipantId): Promise<NonNullablePaths<GetOrCreateConversationResponse, {
        [P in ConversationNonNullablePaths]: `conversation.${P}`;
    }[ConversationNonNullablePaths] | `newConversation`>>;
}
declare const onConversationConversationsMerged$1: EventDefinition<ConversationConversationsMergedEnvelope, "wix.crm.inbox.v2.conversation_conversations_merged">;

declare const getConversation: MaybeContext<BuildRESTFunction<typeof getConversation$1> & typeof getConversation$1>;
declare const getOrCreateConversation: MaybeContext<BuildRESTFunction<typeof getOrCreateConversation$1> & typeof getOrCreateConversation$1>;
/**
 * Triggered when the conversation
 * is merged, for example when contacts are merged
 * or when a visitor becomes a contact.
 *
 * If messages exist in both conversations when they merge,
 * the messages are preserved in chronological order.
 */
declare const onConversationConversationsMerged: BuildEventDefinition<typeof onConversationConversationsMerged$1>;

export { Conversation, ConversationConversationsMergedEnvelope, GetOrCreateConversationResponse, ParticipantId, getConversation, getOrCreateConversation, onConversationConversationsMerged };
