// src/crm-inbox-v2-conversation-conversations.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/crm-inbox-v2-conversation-conversations.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressInboxV2ConversationsServiceUrl(opts) {
  const domainToMappings = {
    "www.wixapis.com": [
      {
        srcPath: "/inbox/v2/conversations",
        destPath: "/v2/conversations"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/inbox-platform-conversations",
        destPath: ""
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/crm/inbox/v2/conversations",
        destPath: "/v2/conversations"
      }
    ],
    _: [
      {
        srcPath: "/crm/inbox/v2/conversations",
        destPath: "/v2/conversations"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_inbox_conversations";
function getConversation(payload) {
  function __getConversation({ host }) {
    const metadata = {
      entityFqdn: "wix.crm.inbox.v2.conversation",
      method: "GET",
      methodFqn: "com.wixpress.inbox.v2.ConversationsService.GetConversation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInboxV2ConversationsServiceUrl({
        protoPath: "/v2/conversations/{conversationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __getConversation;
}
function getOrCreateConversation(payload) {
  function __getOrCreateConversation({ host }) {
    const metadata = {
      entityFqdn: "wix.crm.inbox.v2.conversation",
      method: "POST",
      methodFqn: "com.wixpress.inbox.v2.ConversationsService.GetOrCreateConversation",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressInboxV2ConversationsServiceUrl({
        protoPath: "/v2/conversations",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __getOrCreateConversation;
}

// src/crm-inbox-v2-conversation-conversations.universal.ts
var ChannelType = /* @__PURE__ */ ((ChannelType2) => {
  ChannelType2["UNKNOWN_CHANNEL_TYPE"] = "UNKNOWN_CHANNEL_TYPE";
  ChannelType2["CHAT"] = "CHAT";
  ChannelType2["EMAIL"] = "EMAIL";
  ChannelType2["SMS"] = "SMS";
  ChannelType2["FACEBOOK"] = "FACEBOOK";
  ChannelType2["INSTAGRAM"] = "INSTAGRAM";
  ChannelType2["WHATSAPP"] = "WHATSAPP";
  return ChannelType2;
})(ChannelType || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function getConversation2(conversationId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    conversationId
  });
  const reqOpts = getConversation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.conversation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { conversationId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["conversationId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getOrCreateConversation2(participantId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    participantId
  });
  const reqOpts = getOrCreateConversation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { participantId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["participantId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  ChannelType,
  SortOrder,
  WebhookIdentityType,
  getConversation2 as getConversation,
  getOrCreateConversation2 as getOrCreateConversation
};
//# sourceMappingURL=index.typings.mjs.map