import { GetConversationRequest as GetConversationRequest$1, GetConversationResponse as GetConversationResponse$1, GetOrCreateConversationRequest as GetOrCreateConversationRequest$1, GetOrCreateConversationResponse as GetOrCreateConversationResponse$1 } from './index.typings.js';
import '@wix/sdk-types';

interface Conversation {
    /**
     * Conversation ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * ID of the visitor, contact, or member who is chatting with the business.
     * @readonly
     */
    participant?: IdentificationData;
    /**
     * List of communication channels where the visitor, contact, or member can receive messages.
     * @readonly
     */
    channels?: ChannelTypeWithLiterals[];
    /** Display name and avatar for the business. */
    businessDisplayData?: ConversationDisplayData;
    /** Display name and avatar for the visitor, contact, or member. */
    participantDisplayData?: ConversationDisplayData;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
    /**
     * Contact ID. See the Contacts API for more information.
     * @format GUID
     * @readonly
     */
    contactId?: string | null;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
}
declare enum ChannelType {
    UNKNOWN_CHANNEL_TYPE = "UNKNOWN_CHANNEL_TYPE",
    CHAT = "CHAT",
    EMAIL = "EMAIL",
    SMS = "SMS",
    FACEBOOK = "FACEBOOK",
    INSTAGRAM = "INSTAGRAM",
    WHATSAPP = "WHATSAPP"
}
/** @enumType */
type ChannelTypeWithLiterals = ChannelType | 'UNKNOWN_CHANNEL_TYPE' | 'CHAT' | 'EMAIL' | 'SMS' | 'FACEBOOK' | 'INSTAGRAM' | 'WHATSAPP';
interface ConversationDisplayData {
    /**
     * Display name.
     * @readonly
     */
    name?: string;
    /**
     * Avatar image URL.
     * @readonly
     * @format WEB_URL
     */
    imageUrl?: string | null;
}
interface GetConversationRequest {
    /**
     * Conversation ID.
     * @format GUID
     */
    conversationId: string;
}
interface GetConversationResponse {
    /** Retrieved conversation. */
    conversation?: Conversation;
}
interface GetOrCreateConversationRequest {
    /**
     * ID of the visitor, contact, or member chatting with the business.
     *
     * Required for 3rd-party apps.
     */
    participantId?: ParticipantId;
}
interface ParticipantId extends ParticipantIdIdOneOf {
    /**
     * Contact ID. See the Contacts API for more information.
     * @format GUID
     */
    contactId?: string;
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
}
/** @oneof */
interface ParticipantIdIdOneOf {
    /**
     * Contact ID. See the Contacts API for more information.
     * @format GUID
     */
    contactId?: string;
    /**
     * ID of an anonymous site visitor.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Member ID. See the Members API for more information.
     * @format GUID
     */
    memberId?: string;
}
interface GetOrCreateConversationResponse {
    /** Created or retrieved conversation. */
    conversation?: Conversation;
    /**
     * Indicates whether the conversation previously exists or was just created.
     *
     * If `true`, the conversation was just created.
     * If `false`, the conversation already existed.
     */
    newConversation?: boolean;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function getConversation(): __PublicMethodMetaInfo<'GET', {
    conversationId: string;
}, GetConversationRequest$1, GetConversationRequest, GetConversationResponse$1, GetConversationResponse>;
declare function getOrCreateConversation(): __PublicMethodMetaInfo<'POST', {}, GetOrCreateConversationRequest$1, GetOrCreateConversationRequest, GetOrCreateConversationResponse$1, GetOrCreateConversationResponse>;

export { type __PublicMethodMetaInfo, getConversation, getOrCreateConversation };
